# DataBox
> A user friendly API to jump-start your Deep Learning project. 


The library is still in early development, but a lot of new features will be added in future

    [ ] Support for non-image Datasets
    [ ] Import NN architecture from the timm library
    [ ] Make it better

## Install

`pip install lazybox`

## How to use

Let's go through a very basic example:
